Package: minimalErrorPkg
Title: Minimal error package
Type: Package
Version: 1.0
Date: 2012-04-11
Author: Toby Dylan Hocking 
Maintainer: Toby Dylan Hocking <toby.hocking@inria.fr>
Description: Try to figure out why inlinedocs gets an error.
 If this minimal package makes an error too, then it is
 probably not the fault of inlinedocs.
License: GPL-3


