Package: inlinedocsTest
Title: Various functions to test inlinedocs
Type: Package
Version: 1.0-0
Encoding: latin1
Date: 2010-05-14
Author: Toby Dylan Hocking, Keith Ponting, Philippe Grosjean
Maintainer: Toby Dylan Hocking <toby.hocking@inria.fr>, Keith Ponting <k.ponting@aurix.com>
Description: Generates Rd files from R source code with comments, providing for quick, sustainable package development. The syntax keeps code and documentation close together, and is inspired by the Don't Repeat Yourself principle.
URL: http://inlinedocs.r-forge.r-project.org
Depends: methods, utils
Imports: tools
License: GPL-3
LazyLoad: yes
