Package: inlinedocs
Title: Convert inline comments to documentation
Type: Package
Version: 2013.9.3
Authors@R: c(person("Toby Dylan","Hocking",role=c("aut","cre"),
	   email="toby@sg.cs.titech.ac.jp"),
	  person("Keith","Ponting",role="aut"),
	  person("Thomas","Wutzler",role="aut"),
	  person("Philippe","Grosjean",role="aut"),
	  person("Markus","Müller",role="aut"),
	  person("R Core Team",role=c("ctb","cph")))
Description: Generates Rd files from R source code with comments.
 The main features of the default syntax are that
 (1) docs are defined in comments near the relevant code,
 (2) function argument names are not repeated in comments, and
 (3) examples are defined in R code, not comments.
 It is also easy to define a new syntax.
URL: http://inlinedocs.r-forge.r-project.org
Depends: methods, utils, R (>= 2.9)
License: GPL-2 | GPL-3
LazyLoad: yes
Encoding: UTF-8
Packaged: 2013-09-03 07:45:07 UTC; toby
Author: Toby Dylan Hocking [aut, cre],
  Keith Ponting [aut],
  Thomas Wutzler [aut],
  Philippe Grosjean [aut],
  Markus Müller [aut],
  R Core Team [ctb, cph]
Maintainer: Toby Dylan Hocking <toby@sg.cs.titech.ac.jp>
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2013-09-03 13:04:14
Built: R 3.5.1; ; 2018-10-23 13:54:52 UTC; windows
