\name{silly.example}
\alias{silly.example}
\alias{Long silly alias}
\title{Simple function arguments}
\description{this function does nothing in particular and does it very well
why should I add to description?}
\usage{silly.example()}
\value{always 5}
\author{Toby Dylan Hocking}
