\name{test}
\Rdversion{1.1}
\alias{Iolanthe}
\title{ simple function arguments}
\description{## this function does nothing in particular and does it very well}
\usage{
test(first, second = TRUE)
}
\arguments{
  \item{first}{the first argument}
  \item{second}{the second argument}
}
\details{
if second is TRUE then first is returned


if second is not TRUE then first is negated}
\value{invisible something not unrelated to first}
\references{
}
\author{Toby Dylan Hocking <toby.hocking@etu.upmc.fr>}
\note{
}


\seealso{
}
\examples{}